@@ -5,16 +5,21 @@ from sqlalchemy import (  # noqa: F401
     BigInteger,
     Boolean,
     Column,
+    DateTime,
     Enum,
     Float,
     ForeignKey,
+    Integer,
     String,
     Text,
     UniqueConstraint,
 )
 from sqlalchemy import create_engine as _create_engine
+from sqlalchemy import desc, func  # noqa: F401
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import (  # noqa: F401
+    Load,
+    Query,
     Session,
     declarative_mixin,
     joinedload,
@@ -35,7 +40,8 @@ _conn: Session = None
 def get_db(db_uri: str):
     global _conn
 
-    engine = _create_engine(db_uri, pool_pre_ping=True)
+    # engine = _create_engine(db_uri, pool_pre_ping=True)
+    engine = _create_engine(db_uri)
 
     if _conn is None:
         SessionLocal = sessionmaker(
